﻿using Sugar.Enties;
using SqlSugar;
using System;
using System.Collections.Generic;
using WebAPIBase.Utils;
/// <summary>
/// 待审签证管理类
/// </summary>
public class ViseManager : DbContext<Vise>
{

    //当前类已经继承了 DbContext增、删、查、改的方法

    //这里面写的代码不会给覆盖,如果要重新生成请删除 ViseManager.cs
    /// <summary>
    /// 获取待审签证列表
    /// </summary>
    /// <param name="projectCode"></param>
    /// <param name="searchValue"></param>
    /// <returns></returns>
    public List<ViseDTO> GetVises(string projectCode, string searchValue = "")
    {
        var sql = $"SELECT v.ViseCode,v.ViseId,v.ViseName,v.ViseType,CONVERT(VARCHAR(10),v.ViseDate,120) ViseDate,v.State,dbo.GetUnitFullName(v.UnitCode) unitFullName, c.ContractName,v.ContractCode from Vise v INNER JOIN dbo.Contract c ON v.ContractCode=c.ContractCode where (dbo.GetUnitFullCode(v.UnitCode) like ('100000%')) and v.ProjectCode = '{projectCode}' and v.State ='0'  ";
        if (searchValue.IsNotNullAndEmpty())
        {
            sql += $" and (v.ViseId='{searchValue}' or v.ViseName like '%{searchValue}%')";
        }
        sql += "  order by v.ViseCode desc";
        var list = Db.Ado.SqlQuery<ViseDTO>(sql);
        return list;
    }
    /// <summary>
    /// 根据签证编码获取待审签证实例
    /// </summary>
    /// <param name="viseCode"></param>
    /// <returns></returns>
    public ViseDTO GetVise(string viseCode)
    {
        var sql = $"SELECT v.*,dbo.GetUnitFullName(v.UnitCode) unitFullName, c.ContractName from Vise v INNER JOIN dbo.Contract c ON v.ContractCode=c.ContractCode where  v.viseCode = '{viseCode}'  ";

        var entity = Db.Ado.SqlQuerySingle<ViseDTO>(sql);
        return entity;
    }

    #region 教学方法
    /// <summary>
    /// 如果DbContext中的增删查改方法满足不了你，你可以看下具体用法
    /// </summary>
    public void Study()
    {

        /*********查询*********/

        var data1 = ViseDb.GetById(1);//根据ID查询
        var data2 = ViseDb.GetList();//查询所有
        var data3 = ViseDb.GetList(it => 1 == 1);  //根据条件查询  
        //var data4 = ViseDb.GetSingle(it => 1 == 1);//根据条件查询一条,如果超过一条会报错

        var p = new PageModel() { PageIndex = 1, PageSize = 2 };// 分页查询
        var data5 = ViseDb.GetPageList(it => 1 == 1, p);
        Console.Write(p.PageCount);//返回总数

        var data6 = ViseDb.GetPageList(it => 1 == 1, p, it => SqlFunc.GetRandom(), OrderByType.Asc);// 分页查询加排序
        Console.Write(p.PageCount);//返回总数

        List<IConditionalModel> conModels = new List<IConditionalModel>(); //组装条件查询作为条件实现 分页查询加排序
        conModels.Add(new ConditionalModel() { FieldName = typeof(Vise).GetProperties()[0].Name, ConditionalType = ConditionalType.Equal, FieldValue = "1" });//id=1
        var data7 = ViseDb.GetPageList(conModels, p, it => SqlFunc.GetRandom(), OrderByType.Asc);

        ViseDb.AsQueryable().Where(x => 1 == 1).ToList();//支持了转换成queryable,我们可以用queryable实现复杂功能

        //我要用事务
        var result = Db.Ado.UseTran(() =>
         {
             //写事务代码
         });
        if (result.IsSuccess)
        {
            //事务成功
        }

        //多表查询地址 http://www.codeisbug.com/Doc/8/1124



        /*********插入*********/
        var insertData = new Vise() { };//测试参数
        var insertArray = new Vise[] { insertData };
        ViseDb.Insert(insertData);//插入
        ViseDb.InsertRange(insertArray);//批量插入
        var id = ViseDb.InsertReturnIdentity(insertData);//插入返回自增列
        ViseDb.AsInsertable(insertData).ExecuteCommand();//我们可以转成 Insertable实现复杂插入



        /*********更新*********/
        var updateData = new Vise() { };//测试参数
        var updateArray = new Vise[] { updateData };//测试参数
        ViseDb.Update(updateData);//根据实体更新
        ViseDb.UpdateRange(updateArray);//批量更新
        //ViseDb.Update(it => new Vise() { Name = "a", CreateTime = DateTime.Now }, it => it.id==1);// 只更新Name列和CreateTime列，其它列不更新，条件id=1
        ViseDb.AsUpdateable(updateData).ExecuteCommand();



        /*********删除*********/
        var deldata = new Vise() { };//测试参数
        ViseDb.Delete(deldata);//根据实体删除
        ViseDb.DeleteById(1);//根据主键删除
        ViseDb.DeleteById(new int[] { 1, 2 });//根据主键数组删除
        ViseDb.Delete(it => 1 == 2);//根据条件删除
        ViseDb.AsDeleteable().Where(it => 1 == 2).ExecuteCommand();//转成Deleteable实现复杂的操作
    }
    #endregion



}
