﻿using NLog;
using Org.BouncyCastle.Bcpg;
using System;
using WebAPIBase.API.Requests;
using WebAPIBase.Service.Interface;
using Newtonsoft.Json;
using System.Net.Http;
using System.Collections.Generic;
using System.Threading.Tasks;
using System.Net;
using Sugar.Enties;
using System.Text;
using WebAPIBase.Utils;
using Microsoft.Extensions.Configuration;
using System.IO;
using System.Collections.Specialized;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Caching.Memory;
using Microsoft.AspNetCore.Authorization;
using System.Drawing;
using Microsoft.AspNetCore.Http;
using System.Linq.Expressions;

namespace WebAPIBase.API.Controllers
{
    /// <summary>
    /// 待审签证
    /// </summary>
    [Produces("application/json;charset=UTF-8")]
    [Route("api/Vise")]
    public class ViseController : Controller
    {
        private static Logger logger = NLog.LogManager.GetCurrentClassLogger();

        /// <summary>
        /// 获取待审签证列表
        /// </summary>
        /// <param name="projectCode"></param>
        /// <param name="searchValue"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetVises")]
        public ActionResult GetVises(string projectCode, string searchValue = "")
        {
            var manager = new ViseManager();
            var list = manager.GetVises(projectCode, searchValue);
            return Json(list);
        }

        /// <summary>
        /// 获取待审签证详情
        /// </summary>
        /// <param name="projectCode"></param>
        /// <param name="searchValue"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetVise")]
        public ActionResult GetVise(string viseCode)
        {
            var manager = new ViseManager();
            var entity = manager.GetVise(viseCode);
            var contract = new ContractManager().GetById(entity.ContractCode);
            if (contract != null)
            {
                entity.SupplierName = new MaterialInManager().GetSupplierNameAndType(contract.SupplierCode, contract.SupplierTypeCode);
            }
            entity.PersonName = new SystemUserManager().GetById(entity.Person)?.UserName;
            entity.RequisitionName = new RequisitionManager().GetById(entity.RequisitionCode)?.RequisitionName;

            var data = new
            {
                mainEntity = entity
            };
            logger.Info($"【GetVise】data:{JsonConvert.SerializeObject(data)}");
            return Json(data);
        }
    }
}
